#ifndef NT2_INCLUDE_CONSTANTS_EXPX2C1_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_EXPX2C1_HPP_INCLUDED

#include <nt2/exponential/include/constants/expx2c1.hpp>

#endif
